@@ -19,7 +19,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(gen_read_table_func);
 
-our $VERSION = '0.34'; # VERSION
+our $VERSION = '0.35'; # VERSION
 
 our %SPEC;
 
@@ -100,48 +100,6 @@ sub _add_arg {
     $func_meta->{args}{$arg_name} = $arg_spec;
 }
 
-sub _add_table_desc_to_func_description {
-    my ($func_meta, $table_spec, $opts) = @_;
-    my $langs = $opts->{langs};
-
-    my $orig_locale = setlocale(LC_ALL);
-
-    for my $lang (@$langs) {
-        setlocale(LC_ALL, $lang) or warn "Can't setlocale $lang";
-        my $td = __("Data is in table form. Table fields are as follow:");
-        $td .= "\n\n";
-        my $ff = $table_spec->{fields};
-        # reminder: index property is for older spec, will be removed someday
-        for my $fn (sort {($ff->{$a}{pos}//$ff->{$a}{index}//0) <=>
-                              ($ff->{$b}{pos}//$ff->{$b}{index}//0)}
-                        keys %$ff) {
-            my $f  = $ff->{$fn};
-            my $fo = Perinci::Object::Metadata->new($f);
-            my $sum = $fo->langprop("summary", {lang=>$lang});
-            $td .=
-                join("",
-                     "  - *$fn*",
-                     $table_spec->{pk} eq $fn ?
-                         " (".__x("ID field").")":"",
-                     $sum ? ": $sum" : "",
-                     "\n\n");
-            my $desc = $fo->langprop("description", {lang=>$lang});
-            if ($desc) {
-                $desc =~ s/^/    /mg;
-                $td .= "$desc\n\n";
-            }
-        }
-
-        my $key = "description" . ($lang eq 'en_US' ? '' : ".alt.lang.$lang");
-        $func_meta->{$key} //= "";
-        $func_meta->{$key} .= "\n" unless $func_meta->{$key} =~ /\n\z/;
-        $func_meta->{$key} .= "\n" unless $func_meta->{$key} !~ /\S/;
-        $func_meta->{$key} .= $td;
-    }
-
-    setlocale(LC_ALL, $orig_locale);
-}
-
 sub _gen_meta {
     my ($table_spec, $opts) = @_;
     my $langs = $opts->{langs};
@@ -160,8 +118,6 @@ sub _gen_meta {
         },
     };
 
-    _add_table_desc_to_func_description($func_meta, $table_spec, $opts);
-
     my $func_args = $func_meta->{args};
 
     _add_arg(
@@ -1309,7 +1265,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its Rinci metadata) to a
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 SYNOPSIS
 
